/* ***** BEGIN LICENSE BLOCK *****
 * FW4SPL - Copyright (C) IRCAD, 2004-2015.
 * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
 * published by the Free Software Foundation.
 * ****** END LICENSE BLOCK ****** */

#ifndef __FWATOMS_NAMESPACE_HPP__
#define __FWATOMS_NAMESPACE_HPP__

/**
 * @namespace   fwAtoms
 *
 *@brief fwAtoms contains basic objects to represent any other kind of object
 *
 * fwAtoms contains seven basic types :
 * \li  Numeric : real and integer type.
 * \li  Boolean : boolean type.
 * \li  String  : String type.
 * \li  Object : complex type.
 * \li  Map : string:Atom association
 * \li  Sequence : sequence of simple Atoms (Numeric, Boolean, String).
 * \li  Blob: representing a raw buffer.
 */
namespace fwAtoms
{
}

#endif /* __FWATOMS_NAMESPACE_HPP__ */

